from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nrt:
	"""Nrt commands group definition. 25 total commands, 3 Sub-groups, 10 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nrt", core, parent)

	@property
	def forward(self):
		"""forward commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_forward'):
			from .Nrt_.Forward import Forward
			self._forward = Forward(self._core, self._base)
		return self._forward

	@property
	def reverse(self):
		"""reverse commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_reverse'):
			from .Nrt_.Reverse import Reverse
			self._reverse = Reverse(self._core, self._base)
		return self._reverse

	@property
	def attenuation(self):
		"""attenuation commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_attenuation'):
			from .Nrt_.Attenuation import Attenuation
			self._attenuation = Attenuation(self._core, self._base)
		return self._attenuation

	def get_scount(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:SCOunt \n
		Snippet: value: int = driver.configure.gprfMeasurement.nrt.get_scount() \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval comprises one set of
		results for both directions. \n
			:return: statistic_count: Range: 1 to 1000
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:SCOunt?')
		return Conversions.str_to_int(response)

	def set_scount(self, statistic_count: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:SCOunt \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_scount(statistic_count = 1) \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval comprises one set of
		results for both directions. \n
			:param statistic_count: Range: 1 to 1000
		"""
		param = Conversions.decimal_value_to_str(statistic_count)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:SCOunt {param}')

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.Repeat:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REPetition \n
		Snippet: value: enums.Repeat = driver.configure.gprfMeasurement.nrt.get_repetition() \n
		Selects whether the measurement is repeated continuously or not. \n
			:return: repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_repetition(self, repetition: enums.Repeat) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REPetition \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_repetition(repetition = enums.Repeat.CONTinuous) \n
		Selects whether the measurement is repeated continuously or not. \n
			:param repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.Repeat)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:REPetition {param}')

	def get_rcoupling(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:RCOupling \n
		Snippet: value: bool = driver.configure.gprfMeasurement.nrt.get_rcoupling() \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:return: repetition_coupl: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:RCOupling?')
		return Conversions.str_to_bool(response)

	def set_rcoupling(self, repetition_coupl: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:RCOupling \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_rcoupling(repetition_coupl = False) \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:param repetition_coupl: OFF | ON
		"""
		param = Conversions.bool_to_str(repetition_coupl)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:RCOupling {param}')

	def get_frequency(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FREQuency \n
		Snippet: value: float = driver.configure.gprfMeasurement.nrt.get_frequency() \n
		Specifies the input frequency at the power sensor. \n
			:return: correction_freq: Range: Depends on the power sensor model , Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, correction_freq: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FREQuency \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_frequency(correction_freq = 1.0) \n
		Specifies the input frequency at the power sensor. \n
			:param correction_freq: Range: Depends on the power sensor model , Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(correction_freq)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:FREQuency {param}')

	def get_cumulative_distrib_fnc(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:CCDF \n
		Snippet: value: float = driver.configure.gprfMeasurement.nrt.get_cumulative_distrib_fnc() \n
		Configures a PEP threshold for calculation of the CCDF result. Note the default value dBm. To enter watts, append W to
		the value, for example 2W. To query watts, append a W to your query: CONFigure:GPRF:MEAS:NRT:CCDF? W. \n
			:return: threshold: Range: 1 W to 300 W, Unit: dBm
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:CCDF?')
		return Conversions.str_to_float(response)

	def set_cumulative_distrib_fnc(self, threshold: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:CCDF \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_cumulative_distrib_fnc(threshold = 1.0) \n
		Configures a PEP threshold for calculation of the CCDF result. Note the default value dBm. To enter watts, append W to
		the value, for example 2W. To query watts, append a W to your query: CONFigure:GPRF:MEAS:NRT:CCDF? W. \n
			:param threshold: Range: 1 W to 300 W, Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(threshold)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:CCDF {param}')

	def get_bandwidth(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:BWIDth \n
		Snippet: value: float = driver.configure.gprfMeasurement.nrt.get_bandwidth() \n
		Sets the video filter bandwidth for the rectified RF signal. \n
			:return: bandwidth: The entered value is rounded to the nearest of the following values: 4 kHz | 200 kHz | 600 kHz Range: 4000 Hz to 600 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:BWIDth?')
		return Conversions.str_to_float(response)

	def set_bandwidth(self, bandwidth: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:BWIDth \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_bandwidth(bandwidth = 1.0) \n
		Sets the video filter bandwidth for the rectified RF signal. \n
			:param bandwidth: The entered value is rounded to the nearest of the following values: 4 kHz | 200 kHz | 600 kHz Range: 4000 Hz to 600 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:BWIDth {param}')

	# noinspection PyTypeChecker
	def get_resolution(self) -> enums.LowHigh:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:RESolution \n
		Snippet: value: enums.LowHigh = driver.configure.gprfMeasurement.nrt.get_resolution() \n
		Selects the measurement resolution. \n
			:return: bandwidth: LOW | HIGH
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:RESolution?')
		return Conversions.str_to_scalar_enum(response, enums.LowHigh)

	def set_resolution(self, bandwidth: enums.LowHigh) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:RESolution \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_resolution(bandwidth = enums.LowHigh.HIGH) \n
		Selects the measurement resolution. \n
			:param bandwidth: LOW | HIGH
		"""
		param = Conversions.enum_scalar_to_str(bandwidth, enums.LowHigh)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:RESolution {param}')

	# noinspection PyTypeChecker
	def get_direction(self) -> enums.PowerSignalDirection:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:DIRection \n
		Snippet: value: enums.PowerSignalDirection = driver.configure.gprfMeasurement.nrt.get_direction() \n
		Defines the forward direction relative to the ports of the power sensor. \n
			:return: direction: FWD | REV | AUTO FWD The forward direction is fixed from port 1 to port 2. REV The forward direction is fixed from port 2 to port 1. AUTO The forward direction is selected automatically.
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:DIRection?')
		return Conversions.str_to_scalar_enum(response, enums.PowerSignalDirection)

	def set_direction(self, direction: enums.PowerSignalDirection) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:DIRection \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_direction(direction = enums.PowerSignalDirection.AUTO) \n
		Defines the forward direction relative to the ports of the power sensor. \n
			:param direction: FWD | REV | AUTO FWD The forward direction is fixed from port 1 to port 2. REV The forward direction is fixed from port 2 to port 1. AUTO The forward direction is selected automatically.
		"""
		param = Conversions.enum_scalar_to_str(direction, enums.PowerSignalDirection)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:DIRection {param}')

	def get_pep_hold_time(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:PEPHoldtime \n
		Snippet: value: float = driver.configure.gprfMeasurement.nrt.get_pep_hold_time() \n
		Sets the hold time for the measurement of the peak envelope power. \n
			:return: pep_hold_time: Range: 1E-3 s to 0.1 s, Unit: s
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:PEPHoldtime?')
		return Conversions.str_to_float(response)

	def set_pep_hold_time(self, pep_hold_time: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:PEPHoldtime \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_pep_hold_time(pep_hold_time = 1.0) \n
		Sets the hold time for the measurement of the peak envelope power. \n
			:param pep_hold_time: Range: 1E-3 s to 0.1 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(pep_hold_time)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:PEPHoldtime {param}')

	# noinspection PyTypeChecker
	def get_device(self) -> enums.NrtDevice:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:DEVice \n
		Snippet: value: enums.NrtDevice = driver.configure.gprfMeasurement.nrt.get_device() \n
		Selects the used power sensor model. \n
			:return: device: N14 | N43 | N44 N14: R&S NRT-Z14 N43: R&S NRT-Z43 N44: R&S NRT-Z44
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:DEVice?')
		return Conversions.str_to_scalar_enum(response, enums.NrtDevice)

	def set_device(self, device: enums.NrtDevice) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:DEVice \n
		Snippet: driver.configure.gprfMeasurement.nrt.set_device(device = enums.NrtDevice.N14) \n
		Selects the used power sensor model. \n
			:param device: N14 | N43 | N44 N14: R&S NRT-Z14 N43: R&S NRT-Z43 N44: R&S NRT-Z44
		"""
		param = Conversions.enum_scalar_to_str(device, enums.NrtDevice)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:DEVice {param}')

	def clone(self) -> 'Nrt':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Nrt(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tsensitivity:
	"""Tsensitivity commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tsensitivity", core, parent)

	@property
	def audioOutput(self):
		"""audioOutput commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_audioOutput'):
			from .Tsensitivity_.AudioOutput import AudioOutput
			self._audioOutput = AudioOutput(self._core, self._base)
		return self._audioOutput

	@property
	def voip(self):
		"""voip commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_voip'):
			from .Tsensitivity_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	def clone(self) -> 'Tsensitivity':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tsensitivity(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MultiEval:
	"""MultiEval commands group definition. 530 total commands, 14 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("multiEval", core, parent)

	@property
	def audioInput(self):
		"""audioInput commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioInput'):
			from .MultiEval_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	@property
	def spdifLeft(self):
		"""spdifLeft commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_spdifLeft'):
			from .MultiEval_.SpdifLeft import SpdifLeft
			self._spdifLeft = SpdifLeft(self._core, self._base)
		return self._spdifLeft

	@property
	def spdifRight(self):
		"""spdifRight commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_spdifRight'):
			from .MultiEval_.SpdifRight import SpdifRight
			self._spdifRight = SpdifRight(self._core, self._base)
		return self._spdifRight

	@property
	def voip(self):
		"""voip commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_voip'):
			from .MultiEval_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	@property
	def demodLeft(self):
		"""demodLeft commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_demodLeft'):
			from .MultiEval_.DemodLeft import DemodLeft
			self._demodLeft = DemodLeft(self._core, self._base)
		return self._demodLeft

	@property
	def demodRight(self):
		"""demodRight commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_demodRight'):
			from .MultiEval_.DemodRight import DemodRight
			self._demodRight = DemodRight(self._core, self._base)
		return self._demodRight

	@property
	def demodulation(self):
		"""demodulation commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_demodulation'):
			from .MultiEval_.Demodulation import Demodulation
			self._demodulation = Demodulation(self._core, self._base)
		return self._demodulation

	@property
	def rfCarrier(self):
		"""rfCarrier commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_rfCarrier'):
			from .MultiEval_.RfCarrier import RfCarrier
			self._rfCarrier = RfCarrier(self._core, self._base)
		return self._rfCarrier

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .MultiEval_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def oscilloscope(self):
		"""oscilloscope commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_oscilloscope'):
			from .MultiEval_.Oscilloscope import Oscilloscope
			self._oscilloscope = Oscilloscope(self._core, self._base)
		return self._oscilloscope

	@property
	def signalQuality(self):
		"""signalQuality commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_signalQuality'):
			from .MultiEval_.SignalQuality import SignalQuality
			self._signalQuality = SignalQuality(self._core, self._base)
		return self._signalQuality

	@property
	def tones(self):
		"""tones commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_tones'):
			from .MultiEval_.Tones import Tones
			self._tones = Tones(self._core, self._base)
		return self._tones

	@property
	def fft(self):
		"""fft commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_fft'):
			from .MultiEval_.Fft import Fft
			self._fft = Fft(self._core, self._base)
		return self._fft

	@property
	def mtones(self):
		"""mtones commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_mtones'):
			from .MultiEval_.Mtones import Mtones
			self._mtones = Mtones(self._core, self._base)
		return self._mtones

	def initiate(self) -> None:
		"""SCPI: INITiate:AFRF:MEASurement<Instance>:MEValuation \n
		Snippet: driver.afRf.measurement.multiEval.initiate() \n
		Starts or continues the analyzer. \n
		"""
		self._core.io.write(f'INITiate:AFRF:MEASurement<Instance>:MEValuation')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:AFRF:MEASurement<Instance>:MEValuation \n
		Snippet: driver.afRf.measurement.multiEval.initiate_with_opc() \n
		Starts or continues the analyzer. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:AFRF:MEASurement<Instance>:MEValuation')

	def stop(self) -> None:
		"""SCPI: STOP:AFRF:MEASurement<Instance>:MEValuation \n
		Snippet: driver.afRf.measurement.multiEval.stop() \n
		Pauses the analyzer. \n
		"""
		self._core.io.write(f'STOP:AFRF:MEASurement<Instance>:MEValuation')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:AFRF:MEASurement<Instance>:MEValuation \n
		Snippet: driver.afRf.measurement.multiEval.stop_with_opc() \n
		Pauses the analyzer. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:AFRF:MEASurement<Instance>:MEValuation')

	def abort(self) -> None:
		"""SCPI: ABORt:AFRF:MEASurement<Instance>:MEValuation \n
		Snippet: driver.afRf.measurement.multiEval.abort() \n
		Stops the analyzer. \n
		"""
		self._core.io.write(f'ABORt:AFRF:MEASurement<Instance>:MEValuation')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:AFRF:MEASurement<Instance>:MEValuation \n
		Snippet: driver.afRf.measurement.multiEval.abort_with_opc() \n
		Stops the analyzer. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:AFRF:MEASurement<Instance>:MEValuation')

	def clone(self) -> 'MultiEval':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MultiEval(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Marker:
	"""Marker commands group definition. 2 total commands, 2 Sub-groups, 0 group commands
	Repeated Capability: MarkerOther, default value after init: MarkerOther.Nr2"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("marker", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_markerOther_get', 'repcap_markerOther_set', repcap.MarkerOther.Nr2)

	def repcap_markerOther_set(self, enum_value: repcap.MarkerOther) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to MarkerOther.Default
		Default value after init: MarkerOther.Nr2"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_markerOther_get(self) -> repcap.MarkerOther:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .Marker_.Enable import Enable
			self._enable = Enable(self._core, self._base)
		return self._enable

	@property
	def placement(self):
		"""placement commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_placement'):
			from .Marker_.Placement import Placement
			self._placement = Placement(self._core, self._base)
		return self._placement

	def clone(self) -> 'Marker':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Marker(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Application:
	"""Application commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("application", core, parent)

	# noinspection PyTypeChecker
	def get_select(self) -> enums.ExtPwrSensorApp:
		"""SCPI: DISPlay:GPRF:MEASurement<Instance>:EPSensor:APPLication:SELect \n
		Snippet: value: enums.ExtPwrSensorApp = driver.display.gprfMeasurement.extPwrSensor.application.get_select() \n
		Configures the display of the 'Sensor' tab. \n
			:return: application: EPS | NRTZ Show 'EPS' subtab or 'NRT-Z' subtab
		"""
		response = self._core.io.query_str('DISPlay:GPRF:MEASurement<Instance>:EPSensor:APPLication:SELect?')
		return Conversions.str_to_scalar_enum(response, enums.ExtPwrSensorApp)

	def set_select(self, application: enums.ExtPwrSensorApp) -> None:
		"""SCPI: DISPlay:GPRF:MEASurement<Instance>:EPSensor:APPLication:SELect \n
		Snippet: driver.display.gprfMeasurement.extPwrSensor.application.set_select(application = enums.ExtPwrSensorApp.EPS) \n
		Configures the display of the 'Sensor' tab. \n
			:param application: EPS | NRTZ Show 'EPS' subtab or 'NRT-Z' subtab
		"""
		param = Conversions.enum_scalar_to_str(application, enums.ExtPwrSensorApp)
		self._core.io.write(f'DISPlay:GPRF:MEASurement<Instance>:EPSensor:APPLication:SELect {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .....Internal.Types import DataType
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Zero:
	"""Zero commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("zero", core, parent)

	def set(self) -> None:
		"""SCPI: CALibration:GPRF:MEASurement<Instance>:NRT:ZERO \n
		Snippet: driver.calibration.gprfMeasurement.nrt.zero.set() \n
		Initiates zeroing of the power sensor. A query returns whether the zeroing was successful. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
		"""
		self._core.io.write(f'CALibration:GPRF:MEASurement<Instance>:NRT:ZERO')

	def set_with_opc(self) -> None:
		"""SCPI: CALibration:GPRF:MEASurement<Instance>:NRT:ZERO \n
		Snippet: driver.calibration.gprfMeasurement.nrt.zero.set_with_opc() \n
		Initiates zeroing of the power sensor. A query returns whether the zeroing was successful. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'CALibration:GPRF:MEASurement<Instance>:NRT:ZERO')

	# noinspection PyTypeChecker
	def get(self) -> enums.Status:
		"""SCPI: CALibration:GPRF:MEASurement<Instance>:NRT:ZERO \n
		Snippet: value: enums.Status = driver.calibration.gprfMeasurement.nrt.zero.get() \n
		Initiates zeroing of the power sensor. A query returns whether the zeroing was successful. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: zeroing_state: PASSed | FAILed"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'CALibration:GPRF:MEASurement<Instance>:NRT:ZERO?', suppressed)
		return Conversions.str_to_scalar_enum(response, enums.Status)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Delta:
	"""Delta commands group definition. 4 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("delta", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Delta_.Mode import Mode
			self._mode = Mode(self._core, self._base)
		return self._mode

	@property
	def user(self):
		"""user commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_user'):
			from .Delta_.User import User
			self._user = User(self._core, self._base)
		return self._user

	@property
	def measured(self):
		"""measured commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_measured'):
			from .Delta_.Measured import Measured
			self._measured = Measured(self._core, self._base)
		return self._measured

	@property
	def update(self):
		"""update commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_update'):
			from .Delta_.Update import Update
			self._update = Update(self._core, self._base)
		return self._update

	def clone(self) -> 'Delta':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Delta(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Result:
	"""Result commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("result", core, parent)

	# noinspection PyTypeChecker
	def get_overview(self) -> enums.OverviewType:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:OVERview \n
		Snippet: value: enums.OverviewType = driver.configure.afRf.measurement.multiEval.result.get_overview() \n
		No command help available \n
			:return: type_py: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:OVERview?')
		return Conversions.str_to_scalar_enum(response, enums.OverviewType)

	def set_overview(self, type_py: enums.OverviewType) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:OVERview \n
		Snippet: driver.configure.afRf.measurement.multiEval.result.set_overview(type_py = enums.OverviewType.FFT) \n
		No command help available \n
			:param type_py: No help available
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.OverviewType)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:OVERview {param}')

	def get_oscilloscope(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:OSCilloscope \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.result.get_oscilloscope() \n
		Enables or disables the measurement of the AF oscilloscope results. \n
			:return: osc_enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:OSCilloscope?')
		return Conversions.str_to_bool(response)

	def set_oscilloscope(self, osc_enable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:OSCilloscope \n
		Snippet: driver.configure.afRf.measurement.multiEval.result.set_oscilloscope(osc_enable = False) \n
		Enables or disables the measurement of the AF oscilloscope results. \n
			:param osc_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(osc_enable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:OSCilloscope {param}')

	def get_fft(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:FFT \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.result.get_fft() \n
		Enables or disables the measurement of the AF spectrum results. \n
			:return: fft_enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:FFT?')
		return Conversions.str_to_bool(response)

	def set_fft(self, fft_enable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:FFT \n
		Snippet: driver.configure.afRf.measurement.multiEval.result.set_fft(fft_enable = False) \n
		Enables or disables the measurement of the AF spectrum results. \n
			:param fft_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(fft_enable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:RESult:FFT {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scal:
	"""Scal commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("scal", core, parent)

	# noinspection PyTypeChecker
	class FdeviationStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower frequency-deviation limit Range: -100 % to 0 %, Unit: %
			- Upper: float: Upper frequency-deviation limit Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_fdeviation(self) -> FdeviationStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:FDEViation \n
		Snippet: value: FdeviationStruct = driver.configure.afRf.measurement.multiEval.limit.tones.scal.get_fdeviation() \n
		Configures limits for the frequency deviation of tones in an analyzed SELCAL sequence. \n
			:return: structure: for return value, see the help for FdeviationStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:FDEViation?', self.__class__.FdeviationStruct())

	def set_fdeviation(self, value: FdeviationStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:FDEViation \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.tones.scal.set_fdeviation(value = FdeviationStruct()) \n
		Configures limits for the frequency deviation of tones in an analyzed SELCAL sequence. \n
			:param value: see the help for FdeviationStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:FDEViation', value)

	# noinspection PyTypeChecker
	class TtimeStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower tone-duration limit Range: 0.1 s to 1 s, Unit: s
			- Upper: float: Upper tone-duration limit Range: 1 s to 3 s, Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_ttime(self) -> TtimeStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:TTIMe \n
		Snippet: value: TtimeStruct = driver.configure.afRf.measurement.multiEval.limit.tones.scal.get_ttime() \n
		Configures limits for the tone duration in an analyzed SELCAL sequence. \n
			:return: structure: for return value, see the help for TtimeStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:TTIMe?', self.__class__.TtimeStruct())

	def set_ttime(self, value: TtimeStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:TTIMe \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.tones.scal.set_ttime(value = TtimeStruct()) \n
		Configures limits for the tone duration in an analyzed SELCAL sequence. \n
			:param value: see the help for TtimeStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:TTIMe', value)

	# noinspection PyTypeChecker
	class TpauseStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower pause limit Range: 0.1 s to 0.25 s, Unit: s
			- Upper: float: Upper pause limit Range: 0.25 s to 3 s, Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_tpause(self) -> TpauseStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:TPAuse \n
		Snippet: value: TpauseStruct = driver.configure.afRf.measurement.multiEval.limit.tones.scal.get_tpause() \n
		Configures limits for the pause between two dual tones of an analyzed SELCAL sequence. \n
			:return: structure: for return value, see the help for TpauseStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:TPAuse?', self.__class__.TpauseStruct())

	def set_tpause(self, value: TpauseStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:TPAuse \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.tones.scal.set_tpause(value = TpauseStruct()) \n
		Configures limits for the pause between two dual tones of an analyzed SELCAL sequence. \n
			:param value: see the help for TpauseStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:SCAL:TPAuse', value)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spectrum:
	"""Spectrum commands group definition. 56 total commands, 11 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spectrum", core, parent)

	@property
	def tgenerator(self):
		"""tgenerator commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tgenerator'):
			from .Spectrum_.Tgenerator import Tgenerator
			self._tgenerator = Tgenerator(self._core, self._base)
		return self._tgenerator

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Spectrum_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Spectrum_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def zeroSpan(self):
		"""zeroSpan commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_zeroSpan'):
			from .Spectrum_.ZeroSpan import ZeroSpan
			self._zeroSpan = ZeroSpan(self._core, self._base)
		return self._zeroSpan

	@property
	def referenceMarker(self):
		"""referenceMarker commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_referenceMarker'):
			from .Spectrum_.ReferenceMarker import ReferenceMarker
			self._referenceMarker = ReferenceMarker(self._core, self._base)
		return self._referenceMarker

	@property
	def sample(self):
		"""sample commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_sample'):
			from .Spectrum_.Sample import Sample
			self._sample = Sample(self._core, self._base)
		return self._sample

	@property
	def rms(self):
		"""rms commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_rms'):
			from .Spectrum_.Rms import Rms
			self._rms = Rms(self._core, self._base)
		return self._rms

	@property
	def maximum(self):
		"""maximum commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_maximum'):
			from .Spectrum_.Maximum import Maximum
			self._maximum = Maximum(self._core, self._base)
		return self._maximum

	@property
	def minimum(self):
		"""minimum commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_minimum'):
			from .Spectrum_.Minimum import Minimum
			self._minimum = Minimum(self._core, self._base)
		return self._minimum

	@property
	def average(self):
		"""average commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_average'):
			from .Spectrum_.Average import Average
			self._average = Average(self._core, self._base)
		return self._average

	@property
	def freqSweep(self):
		"""freqSweep commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_freqSweep'):
			from .Spectrum_.FreqSweep import FreqSweep
			self._freqSweep = FreqSweep(self._core, self._base)
		return self._freqSweep

	def initiate(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:SPECtrum \n
		Snippet: driver.gprfMeasurement.spectrum.initiate() \n
		Starts or continues the spectrum analyzer. \n
		"""
		self._core.io.write(f'INITiate:GPRF:MEASurement<Instance>:SPECtrum')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:SPECtrum \n
		Snippet: driver.gprfMeasurement.spectrum.initiate_with_opc() \n
		Starts or continues the spectrum analyzer. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:GPRF:MEASurement<Instance>:SPECtrum')

	def stop(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:SPECtrum \n
		Snippet: driver.gprfMeasurement.spectrum.stop() \n
		Pauses the spectrum analyzer. \n
		"""
		self._core.io.write(f'STOP:GPRF:MEASurement<Instance>:SPECtrum')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:SPECtrum \n
		Snippet: driver.gprfMeasurement.spectrum.stop_with_opc() \n
		Pauses the spectrum analyzer. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:GPRF:MEASurement<Instance>:SPECtrum')

	def abort(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:SPECtrum \n
		Snippet: driver.gprfMeasurement.spectrum.abort() \n
		Stops the spectrum analyzer. \n
		"""
		self._core.io.write(f'ABORt:GPRF:MEASurement<Instance>:SPECtrum')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:SPECtrum \n
		Snippet: driver.gprfMeasurement.spectrum.abort_with_opc() \n
		Stops the spectrum analyzer. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:GPRF:MEASurement<Instance>:SPECtrum')

	def clone(self) -> 'Spectrum':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Spectrum(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: No parameter help available
			- Rms: float: No parameter help available
			- Peak: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Rms'),
			ArgStruct.scalar_float('Peak')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Rms: float = None
			self.Peak: float = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:VSE:MEASurement<Instance>:EVM:CURRent \n
		Snippet: value: ResultData = driver.vse.measurement.evm.current.fetch() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:VSE:MEASurement<Instance>:EVM:CURRent?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:VSE:MEASurement<Instance>:EVM:CURRent \n
		Snippet: value: ResultData = driver.vse.measurement.evm.current.read() \n
		No command help available \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:VSE:MEASurement<Instance>:EVM:CURRent?', self.__class__.ResultData())

	# noinspection PyTypeChecker
	class CalculateStruct(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: No parameter help available
			- Rms: enums.ResultStatus: No parameter help available
			- Peak: enums.ResultStatus: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_enum('Rms', enums.ResultStatus),
			ArgStruct.scalar_enum('Peak', enums.ResultStatus)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Rms: enums.ResultStatus = None
			self.Peak: enums.ResultStatus = None

	def calculate(self) -> CalculateStruct:
		"""SCPI: CALCulate:VSE:MEASurement<Instance>:EVM:CURRent \n
		Snippet: value: CalculateStruct = driver.vse.measurement.evm.current.calculate() \n
		No command help available \n
			:return: structure: for return value, see the help for CalculateStruct structure arguments."""
		return self._core.io.query_struct(f'CALCulate:VSE:MEASurement<Instance>:EVM:CURRent?', self.__class__.CalculateStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cdefinition:
	"""Cdefinition commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cdefinition", core, parent)

	def get_rchannel(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:CDEFinition:RCHannel \n
		Snippet: value: int = driver.source.afRf.generator.cdefinition.get_rchannel() \n
		Assigns a reference channel number to the reference frequency defined via method RsCma.Source.AfRf.Generator.Cdefinition.
		rfrequency. This setting is part of the channel definition. \n
			:return: reference_ch: Range: 0 Ch to 9999 Ch, Unit: Ch
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:CDEFinition:RCHannel?')
		return Conversions.str_to_int(response)

	def set_rchannel(self, reference_ch: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:CDEFinition:RCHannel \n
		Snippet: driver.source.afRf.generator.cdefinition.set_rchannel(reference_ch = 1) \n
		Assigns a reference channel number to the reference frequency defined via method RsCma.Source.AfRf.Generator.Cdefinition.
		rfrequency. This setting is part of the channel definition. \n
			:param reference_ch: Range: 0 Ch to 9999 Ch, Unit: Ch
		"""
		param = Conversions.decimal_value_to_str(reference_ch)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:CDEFinition:RCHannel {param}')

	def get_rfrequency(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:CDEFinition:RFRequency \n
		Snippet: value: float = driver.source.afRf.generator.cdefinition.get_rfrequency() \n
		Assigns a reference frequency to the reference channel number defined via method RsCma.Source.AfRf.Generator.Cdefinition.
		rchannel. This setting is part of the channel definition. \n
			:return: reference_freq: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:CDEFinition:RFRequency?')
		return Conversions.str_to_float(response)

	def set_rfrequency(self, reference_freq: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:CDEFinition:RFRequency \n
		Snippet: driver.source.afRf.generator.cdefinition.set_rfrequency(reference_freq = 1.0) \n
		Assigns a reference frequency to the reference channel number defined via method RsCma.Source.AfRf.Generator.Cdefinition.
		rchannel. This setting is part of the channel definition. \n
			:param reference_freq: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(reference_freq)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:CDEFinition:RFRequency {param}')

	def get_cspace(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:CDEFinition:CSPace \n
		Snippet: value: float = driver.source.afRf.generator.cdefinition.get_cspace() \n
		Defines the channel spacing, that is the center frequency difference of two adjacent channels. This setting is part of
		the channel definition. \n
			:return: channel_space: Range: 100 Hz to 4 MHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:CDEFinition:CSPace?')
		return Conversions.str_to_float(response)

	def set_cspace(self, channel_space: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:CDEFinition:CSPace \n
		Snippet: driver.source.afRf.generator.cdefinition.set_cspace(channel_space = 1.0) \n
		Defines the channel spacing, that is the center frequency difference of two adjacent channels. This setting is part of
		the channel definition. \n
			:param channel_space: Range: 100 Hz to 4 MHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(channel_space)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:CDEFinition:CSPace {param}')

	def get_value(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:CDEFinition \n
		Snippet: value: bool = driver.source.afRf.generator.cdefinition.get_value() \n
		Activates or deactivates the channel definition. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:CDEFinition?')
		return Conversions.str_to_bool(response)

	def set_value(self, enable: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:CDEFinition \n
		Snippet: driver.source.afRf.generator.cdefinition.set_value(enable = False) \n
		Activates or deactivates the channel definition. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:CDEFinition {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fdialing:
	"""Fdialing commands group definition. 7 total commands, 1 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fdialing", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Fdialing_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	def get_cfgenerator(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:CFGenerator \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.tones.fdialing.get_cfgenerator() \n
		Couples the free-dialing tone settings of the analyzer to the corresponding generator settings. \n
			:return: conf_from_gen: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:CFGenerator?')
		return Conversions.str_to_bool(response)

	def set_cfgenerator(self, conf_from_gen: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:CFGenerator \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.fdialing.set_cfgenerator(conf_from_gen = False) \n
		Couples the free-dialing tone settings of the analyzer to the corresponding generator settings. \n
			:param conf_from_gen: OFF | ON
		"""
		param = Conversions.bool_to_str(conf_from_gen)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:CFGenerator {param}')

	# noinspection PyTypeChecker
	def get_efrequency(self) -> enums.ExpFrequency:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:EFRequency \n
		Snippet: value: enums.ExpFrequency = driver.configure.afRf.measurement.multiEval.tones.fdialing.get_efrequency() \n
		No command help available \n
			:return: exp_frequency: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:EFRequency?')
		return Conversions.str_to_scalar_enum(response, enums.ExpFrequency)

	def set_efrequency(self, exp_frequency: enums.ExpFrequency) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:EFRequency \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.fdialing.set_efrequency(exp_frequency = enums.ExpFrequency.CONF) \n
		No command help available \n
			:param exp_frequency: No help available
		"""
		param = Conversions.enum_scalar_to_str(exp_frequency, enums.ExpFrequency)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:EFRequency {param}')

	# noinspection PyTypeChecker
	def get_ttype(self) -> enums.SingDualToneType:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:TTYPe \n
		Snippet: value: enums.SingDualToneType = driver.configure.afRf.measurement.multiEval.tones.fdialing.get_ttype() \n
		Selects a tone type for free-dialing tone sequence analysis. \n
			:return: tone_type: STONe | DTONe Single tones or dual tones
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:TTYPe?')
		return Conversions.str_to_scalar_enum(response, enums.SingDualToneType)

	def set_ttype(self, tone_type: enums.SingDualToneType) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:TTYPe \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.fdialing.set_ttype(tone_type = enums.SingDualToneType.DTONe) \n
		Selects a tone type for free-dialing tone sequence analysis. \n
			:param tone_type: STONe | DTONe Single tones or dual tones
		"""
		param = Conversions.enum_scalar_to_str(tone_type, enums.SingDualToneType)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:TTYPe {param}')

	def get_slength(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:SLENgth \n
		Snippet: value: int = driver.configure.afRf.measurement.multiEval.tones.fdialing.get_slength() \n
		Specifies the expected length of the analyzed free-dialing tone sequence (number of digits) . \n
			:return: seq_length: Range: 1 to 42
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:SLENgth?')
		return Conversions.str_to_int(response)

	def set_slength(self, seq_length: int) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:SLENgth \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.fdialing.set_slength(seq_length = 1) \n
		Specifies the expected length of the analyzed free-dialing tone sequence (number of digits) . \n
			:param seq_length: Range: 1 to 42
		"""
		param = Conversions.decimal_value_to_str(seq_length)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:SLENgth {param}')

	# noinspection PyTypeChecker
	def get_maccuracy(self) -> enums.MeasAccuracy:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:MACCuracy \n
		Snippet: value: enums.MeasAccuracy = driver.configure.afRf.measurement.multiEval.tones.fdialing.get_maccuracy() \n
		Configures the accuracy of the analysis of free-dialing single-tone sequences. \n
			:return: meas_accuracy: NORMal | HIGH NORMal: lower tone detection accuracy / minimum pause length HIGH: higher tone detection accuracy / minimum pause length
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:MACCuracy?')
		return Conversions.str_to_scalar_enum(response, enums.MeasAccuracy)

	def set_maccuracy(self, meas_accuracy: enums.MeasAccuracy) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:MACCuracy \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.fdialing.set_maccuracy(meas_accuracy = enums.MeasAccuracy.HIGH) \n
		Configures the accuracy of the analysis of free-dialing single-tone sequences. \n
			:param meas_accuracy: NORMal | HIGH NORMal: lower tone detection accuracy / minimum pause length HIGH: higher tone detection accuracy / minimum pause length
		"""
		param = Conversions.enum_scalar_to_str(meas_accuracy, enums.MeasAccuracy)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:FDIaling:MACCuracy {param}')

	def clone(self) -> 'Fdialing':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Fdialing(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sout:
	"""Sout commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sout", core, parent)

	# noinspection PyTypeChecker
	class LevelStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Level_Left: float: Level for the left channel Range: 0.01 % to 100 %, Unit: %
			- Level_Right: float: Level for the right channel Range: 0.01 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_float('Level_Left'),
			ArgStruct.scalar_float('Level_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Level_Left: float = None
			self.Level_Right: float = None

	def get_level(self) -> LevelStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:SOUT:LEVel \n
		Snippet: value: LevelStruct = driver.source.afRf.generator.sout.get_level() \n
		Specifies the output levels for the SPDIF OUT connector. For noise signals provided by an internal generator, the maximum
		allowed level is reduced by the factor 1/sqrt(2) . \n
			:return: structure: for return value, see the help for LevelStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:AFRF:GENerator<Instance>:SOUT:LEVel?', self.__class__.LevelStruct())

	def set_level(self, value: LevelStruct) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:SOUT:LEVel \n
		Snippet: driver.source.afRf.generator.sout.set_level(value = LevelStruct()) \n
		Specifies the output levels for the SPDIF OUT connector. For noise signals provided by an internal generator, the maximum
		allowed level is reduced by the factor 1/sqrt(2) . \n
			:param value: see the help for LevelStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce:AFRF:GENerator<Instance>:SOUT:LEVel', value)

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Left: bool: OFF | ON
			- Right: bool: OFF | ON"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Left'),
			ArgStruct.scalar_bool('Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Left: bool = None
			self.Right: bool = None

	def get_enable(self) -> EnableStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:SOUT:ENABle \n
		Snippet: value: EnableStruct = driver.source.afRf.generator.sout.get_enable() \n
		Enables or disables the left and right channel of the SPDIF OUT connector. \n
			:return: structure: for return value, see the help for EnableStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:AFRF:GENerator<Instance>:SOUT:ENABle?', self.__class__.EnableStruct())

	def set_enable(self, value: EnableStruct) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:SOUT:ENABle \n
		Snippet: driver.source.afRf.generator.sout.set_enable(value = EnableStruct()) \n
		Enables or disables the left and right channel of the SPDIF OUT connector. \n
			:param value: see the help for EnableStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce:AFRF:GENerator<Instance>:SOUT:ENABle', value)

	# noinspection PyTypeChecker
	class ValueStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Source_Left: enums.SignalSource: GEN3 | AFI1 | SPIL GEN3 Audio generator 3 AFI1 AF1 IN SPIL SPDIF IN, left channel
			- Source_Right: enums.SignalSource: GEN4 | AFI2 | SPIR GEN4 Audio generator 4 AFI2 AF2 IN SPIR SPDIF IN, right channel"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Source_Left', enums.SignalSource),
			ArgStruct.scalar_enum('Source_Right', enums.SignalSource)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Source_Left: enums.SignalSource = None
			self.Source_Right: enums.SignalSource = None

	# noinspection PyTypeChecker
	def get_value(self) -> ValueStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:SOUT \n
		Snippet: value: ValueStruct = driver.source.afRf.generator.sout.get_value() \n
		Selects audio signal sources for the left and right channel of the SPDIF OUT connector. \n
			:return: structure: for return value, see the help for ValueStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:AFRF:GENerator<Instance>:SOUT?', self.__class__.ValueStruct())

	def set_value(self, value: ValueStruct) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:SOUT \n
		Snippet: driver.source.afRf.generator.sout.set_value(value = ValueStruct()) \n
		Selects audio signal sources for the left and right channel of the SPDIF OUT connector. \n
			:param value: see the help for ValueStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce:AFRF:GENerator<Instance>:SOUT', value)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class First:
	"""First commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("first", core, parent)

	def get_mlevel(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:AIN:FIRSt:MLEVel \n
		Snippet: value: float = driver.source.afRf.generator.audioInput.first.get_mlevel() \n
		Specifies the maximum expected level for the AF1 IN connector. This setting is only relevant, if auto ranging is disabled. \n
			:return: level: Maximum expected level Range: 10E-6 V to 43 V, Unit: V
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:AIN:FIRSt:MLEVel?')
		return Conversions.str_to_float(response)

	def set_mlevel(self, level: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:AIN:FIRSt:MLEVel \n
		Snippet: driver.source.afRf.generator.audioInput.first.set_mlevel(level = 1.0) \n
		Specifies the maximum expected level for the AF1 IN connector. This setting is only relevant, if auto ranging is disabled. \n
			:param level: Maximum expected level Range: 10E-6 V to 43 V, Unit: V
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:AIN:FIRSt:MLEVel {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Level:
	"""Level commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("level", core, parent)

	def set(self, level: float, audioOutput=repcap.AudioOutput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AOUT<nr>:LEVel \n
		Snippet: driver.configure.afRf.measurement.audioOutput.level.set(level = 1.0, audioOutput = repcap.AudioOutput.Default) \n
		Specifies the output level for an AF OUT connector in voltage-related units (Table 'Units relevant for remote commands') .
		The command sets the same unit for both AF OUT connectors. If you want to set different level units (e.g. dBm) or set
		level for both connectors independently, use method RsCma.Configure.AfRf.Measurement.AudioOutput.First.level for AF1 OUT
		and method RsCma.Configure.AfRf.Measurement.AudioOutput.Second.level for AF2 OUT. \n
			:param level: Range: 10E-6 V to 5 V, Unit: V
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')"""
		param = Conversions.decimal_value_to_str(level)
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AOUT{audioOutput_cmd_val}:LEVel {param}')

	def get(self, audioOutput=repcap.AudioOutput.Default) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AOUT<nr>:LEVel \n
		Snippet: value: float = driver.configure.afRf.measurement.audioOutput.level.get(audioOutput = repcap.AudioOutput.Default) \n
		Specifies the output level for an AF OUT connector in voltage-related units (Table 'Units relevant for remote commands') .
		The command sets the same unit for both AF OUT connectors. If you want to set different level units (e.g. dBm) or set
		level for both connectors independently, use method RsCma.Configure.AfRf.Measurement.AudioOutput.First.level for AF1 OUT
		and method RsCma.Configure.AfRf.Measurement.AudioOutput.Second.level for AF2 OUT. \n
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')
			:return: level: Range: 10E-6 V to 5 V, Unit: V"""
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AOUT{audioOutput_cmd_val}:LEVel?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Attenuation:
	"""Attenuation commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("attenuation", core, parent)

	def get_state(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:ATTenuation:STATe \n
		Snippet: value: bool = driver.configure.gprfMeasurement.extPwrSensor.attenuation.get_state() \n
		Specifies whether there is an attenuator or amplifier between the power sensor and the DUT. \n
			:return: attenuator_state: OFF | ON OFF Direct connection to DUT ON Attenuator or amplifier between power sensor and DUT. Configure also the attenuation, see method RsCma.Configure.GprfMeasurement.ExtPwrSensor.Attenuation.value.
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:EPSensor:ATTenuation:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, attenuator_state: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:ATTenuation:STATe \n
		Snippet: driver.configure.gprfMeasurement.extPwrSensor.attenuation.set_state(attenuator_state = False) \n
		Specifies whether there is an attenuator or amplifier between the power sensor and the DUT. \n
			:param attenuator_state: OFF | ON OFF Direct connection to DUT ON Attenuator or amplifier between power sensor and DUT. Configure also the attenuation, see method RsCma.Configure.GprfMeasurement.ExtPwrSensor.Attenuation.value.
		"""
		param = Conversions.bool_to_str(attenuator_state)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:EPSensor:ATTenuation:STATe {param}')

	def get_value(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:ATTenuation \n
		Snippet: value: float = driver.configure.gprfMeasurement.extPwrSensor.attenuation.get_value() \n
		Specifies the attenuation or gain of a component between the power sensor and the DUT. The power readings are corrected
		accordingly. Configure also the attenuation state, see method RsCma.Configure.GprfMeasurement.ExtPwrSensor.Attenuation.
		state. \n
			:return: attenuation: Range: -50 dB to 50 dB, Unit: dB
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:EPSensor:ATTenuation?')
		return Conversions.str_to_float(response)

	def set_value(self, attenuation: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:EPSensor:ATTenuation \n
		Snippet: driver.configure.gprfMeasurement.extPwrSensor.attenuation.set_value(attenuation = 1.0) \n
		Specifies the attenuation or gain of a component between the power sensor and the DUT. The power readings are corrected
		accordingly. Configure also the attenuation state, see method RsCma.Configure.GprfMeasurement.ExtPwrSensor.Attenuation.
		state. \n
			:param attenuation: Range: -50 dB to 50 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(attenuation)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:EPSensor:ATTenuation {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("filterPy", core, parent)

	# noinspection PyTypeChecker
	class FilterPyStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Binput: bool: No parameter help available
			- Boutput: bool: No parameter help available
			- Berror: bool: No parameter help available
			- Btrigger: bool: No parameter help available
			- Bdevice_Clear: bool: No parameter help available
			- Bstatus_Register: bool: No parameter help available
			- Bconnection: bool: No parameter help available
			- Bremote_Local_Events: bool: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Binput'),
			ArgStruct.scalar_bool('Boutput'),
			ArgStruct.scalar_bool('Berror'),
			ArgStruct.scalar_bool('Btrigger'),
			ArgStruct.scalar_bool('Bdevice_Clear'),
			ArgStruct.scalar_bool('Bstatus_Register'),
			ArgStruct.scalar_bool('Bconnection'),
			ArgStruct.scalar_bool('Bremote_Local_Events')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Binput: bool = None
			self.Boutput: bool = None
			self.Berror: bool = None
			self.Btrigger: bool = None
			self.Bdevice_Clear: bool = None
			self.Bstatus_Register: bool = None
			self.Bconnection: bool = None
			self.Bremote_Local_Events: bool = None

	def set(self, structure: FilterPyStruct, instrument=repcap.Instrument.Default) -> None:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:FILTer \n
		Snippet: driver.trace.remote.mode.file.filterPy.set(value = [PROPERTY_STRUCT_NAME](), instrument = repcap.Instrument.Default) \n
		Specifies a filter for tracing of the remote control interface. The filter defines which message types and events are
		traced to a file. \n
			:param structure: for set value, see the help for FilterPyStruct structure arguments.
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')"""
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		self._core.io.write_struct(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:FILTer', structure)

	def get(self, instrument=repcap.Instrument.Default) -> FilterPyStruct:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:FILTer \n
		Snippet: value: FilterPyStruct = driver.trace.remote.mode.file.filterPy.get(instrument = repcap.Instrument.Default) \n
		Specifies a filter for tracing of the remote control interface. The filter defines which message types and events are
		traced to a file. \n
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')
			:return: structure: for return value, see the help for FilterPyStruct structure arguments."""
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		return self._core.io.query_struct(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:FILTer?', self.__class__.FilterPyStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ssb:
	"""Ssb commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ssb", core, parent)

	def get_threshold(self) -> float:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:SSB:THReshold \n
		Snippet: value: float = driver.trigger.afRf.measurement.multiEval.oscilloscope.demodulation.ssb.get_threshold() \n
		Defines the trigger threshold for the RF input path, for SSB demodulation. \n
			:return: threshold: Audio level threshold Range: -30 V to 30 V, Unit: V
		"""
		response = self._core.io.query_str('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:SSB:THReshold?')
		return Conversions.str_to_float(response)

	def set_threshold(self, threshold: float) -> None:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:SSB:THReshold \n
		Snippet: driver.trigger.afRf.measurement.multiEval.oscilloscope.demodulation.ssb.set_threshold(threshold = 1.0) \n
		Defines the trigger threshold for the RF input path, for SSB demodulation. \n
			:param threshold: Audio level threshold Range: -30 V to 30 V, Unit: V
		"""
		param = Conversions.decimal_value_to_str(threshold)
		self._core.io.write(f'TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:SSB:THReshold {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Weighting:
	"""Weighting commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("weighting", core, parent)

	def set(self, filter_py: enums.WeightingFilter, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FILTer:WEIGhting \n
		Snippet: driver.configure.afRf.measurement.audioInput.filterPy.weighting.set(filter_py = enums.WeightingFilter.AWEighting, audioInput = repcap.AudioInput.Default) \n
		Configures the weighting filter in an AF input path. \n
			:param filter_py: OFF | AWEighting | CCITt | CMESsage OFF Filter disabled AWEighting A-weighting filter CCITt CCITT weighting filter CMESsage C-message weighting filter
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.enum_scalar_to_str(filter_py, enums.WeightingFilter)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FILTer:WEIGhting {param}')

	# noinspection PyTypeChecker
	def get(self, audioInput=repcap.AudioInput.Default) -> enums.WeightingFilter:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FILTer:WEIGhting \n
		Snippet: value: enums.WeightingFilter = driver.configure.afRf.measurement.audioInput.filterPy.weighting.get(audioInput = repcap.AudioInput.Default) \n
		Configures the weighting filter in an AF input path. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: filter_py: OFF | AWEighting | CCITt | CMESsage OFF Filter disabled AWEighting A-weighting filter CCITt CCITT weighting filter CMESsage C-message weighting filter"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FILTer:WEIGhting?')
		return Conversions.str_to_scalar_enum(response, enums.WeightingFilter)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spdif:
	"""Spdif commands group definition. 6 total commands, 0 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spdif", core, parent)

	# noinspection PyTypeChecker
	class ThDistortionStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Left: bool: OFF | ON Enables or disables the limit check for the left SPDIF channel
			- Upper_Left: float: Upper THD limit for the left SPDIF channel Range: 0 % to 100 %, Unit: %
			- Enable_Right: bool: OFF | ON Enables or disables the limit check for the right SPDIF channel
			- Upper_Right: float: Upper THD limit for the right SPDIF channel Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Left'),
			ArgStruct.scalar_float('Upper_Left'),
			ArgStruct.scalar_bool('Enable_Right'),
			ArgStruct.scalar_float('Upper_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Left: bool = None
			self.Upper_Left: float = None
			self.Enable_Right: bool = None
			self.Upper_Right: float = None

	def get_th_distortion(self) -> ThDistortionStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:THDistortion \n
		Snippet: value: ThDistortionStruct = driver.configure.afRf.measurement.multiEval.limit.spdif.get_th_distortion() \n
		Configures limits for the THD results, measured via the SPDIF input path. \n
			:return: structure: for return value, see the help for ThDistortionStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:THDistortion?', self.__class__.ThDistortionStruct())

	def set_th_distortion(self, value: ThDistortionStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:THDistortion \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.spdif.set_th_distortion(value = ThDistortionStruct()) \n
		Configures limits for the THD results, measured via the SPDIF input path. \n
			:param value: see the help for ThDistortionStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:THDistortion', value)

	# noinspection PyTypeChecker
	class ThdNoiseStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Left: bool: OFF | ON Enables or disables the limit check for the left SPDIF channel
			- Upper_Left: float: Upper THD+N limit for the left SPDIF channel Range: 0.001 % to 100 %, Unit: %
			- Enable_Right: bool: OFF | ON Enables or disables the limit check for the right SPDIF channel
			- Upper_Right: float: Upper THD+N limit for the right SPDIF channel Range: 0.001 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Left'),
			ArgStruct.scalar_float('Upper_Left'),
			ArgStruct.scalar_bool('Enable_Right'),
			ArgStruct.scalar_float('Upper_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Left: bool = None
			self.Upper_Left: float = None
			self.Enable_Right: bool = None
			self.Upper_Right: float = None

	def get_thd_noise(self) -> ThdNoiseStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:THDNoise \n
		Snippet: value: ThdNoiseStruct = driver.configure.afRf.measurement.multiEval.limit.spdif.get_thd_noise() \n
		Configures limits for the THD+N results, measured via the SPDIF input path. \n
			:return: structure: for return value, see the help for ThdNoiseStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:THDNoise?', self.__class__.ThdNoiseStruct())

	def set_thd_noise(self, value: ThdNoiseStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:THDNoise \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.spdif.set_thd_noise(value = ThdNoiseStruct()) \n
		Configures limits for the THD+N results, measured via the SPDIF input path. \n
			:param value: see the help for ThdNoiseStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:THDNoise', value)

	# noinspection PyTypeChecker
	class SnRatioStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Left: bool: OFF | ON Enables or disables the limit check for the left SPDIF channel
			- Lower_Left: float: Lower limit for the left SPDIF channel Range: 1 dB to 46 dB, Unit: dB
			- Enable_Right: bool: OFF | ON Enables or disables the limit check for the right SPDIF channel
			- Lower_Right: float: Lower limit for the right SPDIF channel Range: 1 dB to 46 dB, Unit: dB
			- Upper_Left: float: Upper limit for the left SPDIF channel Range: 1 dB to 46 dB, Unit: dB
			- Upper_Right: float: Upper limit for the right SPDIF channel Range: 1 dB to 46 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Left'),
			ArgStruct.scalar_float('Lower_Left'),
			ArgStruct.scalar_bool('Enable_Right'),
			ArgStruct.scalar_float('Lower_Right'),
			ArgStruct.scalar_float('Upper_Left'),
			ArgStruct.scalar_float('Upper_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Left: bool = None
			self.Lower_Left: float = None
			self.Enable_Right: bool = None
			self.Lower_Right: float = None
			self.Upper_Left: float = None
			self.Upper_Right: float = None

	def get_sn_ratio(self) -> SnRatioStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNRatio \n
		Snippet: value: SnRatioStruct = driver.configure.afRf.measurement.multiEval.limit.spdif.get_sn_ratio() \n
		Configures limits for all SNR results, measured via the SPDIF input path. SNR results include S/N, (S+N) /N and (S+N+D)
		/N. \n
			:return: structure: for return value, see the help for SnRatioStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNRatio?', self.__class__.SnRatioStruct())

	def set_sn_ratio(self, value: SnRatioStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNRatio \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.spdif.set_sn_ratio(value = SnRatioStruct()) \n
		Configures limits for all SNR results, measured via the SPDIF input path. SNR results include S/N, (S+N) /N and (S+N+D)
		/N. \n
			:param value: see the help for SnRatioStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNRatio', value)

	# noinspection PyTypeChecker
	class SinadStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Left: bool: OFF | ON Enables or disables the limit check for the left SPDIF channel
			- Lower_Left: float: Lower SINAD limit for the left SPDIF channel Range: 0 dB to 140 dB, Unit: dB
			- Enable_Right: bool: OFF | ON Enables or disables the limit check for the right SPDIF channel
			- Lower_Right: float: Lower SINAD limit for the right SPDIF channel Range: 0 dB to 140 dB, Unit: dB
			- Upper_Left: float: Upper SINAD limit for the left SPDIF channel Range: 0 dB to 140 dB, Unit: dB
			- Upper_Right: float: Upper SINAD limit for the right SPDIF channel Range: 0 dB to 140 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Left'),
			ArgStruct.scalar_float('Lower_Left'),
			ArgStruct.scalar_bool('Enable_Right'),
			ArgStruct.scalar_float('Lower_Right'),
			ArgStruct.scalar_float('Upper_Left'),
			ArgStruct.scalar_float('Upper_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Left: bool = None
			self.Lower_Left: float = None
			self.Enable_Right: bool = None
			self.Lower_Right: float = None
			self.Upper_Left: float = None
			self.Upper_Right: float = None

	def get_sinad(self) -> SinadStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SINad \n
		Snippet: value: SinadStruct = driver.configure.afRf.measurement.multiEval.limit.spdif.get_sinad() \n
		Configures limits for the SINAD results, measured via the SPDIF input path. \n
			:return: structure: for return value, see the help for SinadStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SINad?', self.__class__.SinadStruct())

	def set_sinad(self, value: SinadStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SINad \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.spdif.set_sinad(value = SinadStruct()) \n
		Configures limits for the SINAD results, measured via the SPDIF input path. \n
			:param value: see the help for SinadStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SINad', value)

	# noinspection PyTypeChecker
	class SnnRatioStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Left: bool: No parameter help available
			- Lower_Left: float: No parameter help available
			- Enable_Right: bool: No parameter help available
			- Lower_Right: float: No parameter help available
			- Upper_Left: float: No parameter help available
			- Upper_Right: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Left'),
			ArgStruct.scalar_float('Lower_Left'),
			ArgStruct.scalar_bool('Enable_Right'),
			ArgStruct.scalar_float('Lower_Right'),
			ArgStruct.scalar_float('Upper_Left'),
			ArgStruct.scalar_float('Upper_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Left: bool = None
			self.Lower_Left: float = None
			self.Enable_Right: bool = None
			self.Lower_Right: float = None
			self.Upper_Left: float = None
			self.Upper_Right: float = None

	def get_snn_ratio(self) -> SnnRatioStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNNRatio \n
		Snippet: value: SnnRatioStruct = driver.configure.afRf.measurement.multiEval.limit.spdif.get_snn_ratio() \n
		No command help available \n
			:return: structure: for return value, see the help for SnnRatioStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNNRatio?', self.__class__.SnnRatioStruct())

	def set_snn_ratio(self, value: SnnRatioStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNNRatio \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.spdif.set_snn_ratio(value = SnnRatioStruct()) \n
		No command help available \n
			:param value: see the help for SnnRatioStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNNRatio', value)

	# noinspection PyTypeChecker
	class SndRatioStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Left: bool: No parameter help available
			- Lower_Left: float: No parameter help available
			- Enable_Right: bool: No parameter help available
			- Lower_Right: float: No parameter help available
			- Upper_Left: float: No parameter help available
			- Upper_Right: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Left'),
			ArgStruct.scalar_float('Lower_Left'),
			ArgStruct.scalar_bool('Enable_Right'),
			ArgStruct.scalar_float('Lower_Right'),
			ArgStruct.scalar_float('Upper_Left'),
			ArgStruct.scalar_float('Upper_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Left: bool = None
			self.Lower_Left: float = None
			self.Enable_Right: bool = None
			self.Lower_Right: float = None
			self.Upper_Left: float = None
			self.Upper_Right: float = None

	def get_snd_ratio(self) -> SndRatioStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNDRatio \n
		Snippet: value: SndRatioStruct = driver.configure.afRf.measurement.multiEval.limit.spdif.get_snd_ratio() \n
		No command help available \n
			:return: structure: for return value, see the help for SndRatioStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNDRatio?', self.__class__.SndRatioStruct())

	def set_snd_ratio(self, value: SndRatioStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNDRatio \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.spdif.set_snd_ratio(value = SndRatioStruct()) \n
		No command help available \n
			:param value: see the help for SndRatioStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:SIN:SNDRatio', value)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 8 total commands, 1 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Power_.Catalog import Catalog
			self._catalog = Catalog(self._core, self._base)
		return self._catalog

	def get_source(self) -> str:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:SOURce \n
		Snippet: value: str = driver.trigger.gprfMeasurement.power.get_source() \n
		Selects a trigger event source for power measurements. To query a list of all supported sources, use method RsCma.Trigger.
		GprfMeasurement.Power.Catalog.source. \n
			:return: source: Source as string, examples: 'Free Run' Immediate start without trigger signal 'IF Power' Trigger by IF power steps 'Base1: External TRIG In' Trigger signal at connector TRIG IN 'AFRF Gen1: ...' Trigger by processed waveform file
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:POWer:SOURce?')
		return trim_str_response(response)

	def set_source(self, source: str) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:SOURce \n
		Snippet: driver.trigger.gprfMeasurement.power.set_source(source = '1') \n
		Selects a trigger event source for power measurements. To query a list of all supported sources, use method RsCma.Trigger.
		GprfMeasurement.Power.Catalog.source. \n
			:param source: Source as string, examples: 'Free Run' Immediate start without trigger signal 'IF Power' Trigger by IF power steps 'Base1: External TRIG In' Trigger signal at connector TRIG IN 'AFRF Gen1: ...' Trigger by processed waveform file
		"""
		param = Conversions.value_to_quoted_str(source)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:POWer:SOURce {param}')

	def get_mgap(self) -> float:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:MGAP \n
		Snippet: value: float = driver.trigger.gprfMeasurement.power.get_mgap() \n
		Defines the minimum duration of the power-down periods (gaps) between two triggered power pulses. This setting is
		relevant for trigger source 'IF Power'. \n
			:return: minimum_gap: Range: 0 s to 0.01 s, Unit: s
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:POWer:MGAP?')
		return Conversions.str_to_float(response)

	def set_mgap(self, minimum_gap: float) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:MGAP \n
		Snippet: driver.trigger.gprfMeasurement.power.set_mgap(minimum_gap = 1.0) \n
		Defines the minimum duration of the power-down periods (gaps) between two triggered power pulses. This setting is
		relevant for trigger source 'IF Power'. \n
			:param minimum_gap: Range: 0 s to 0.01 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(minimum_gap)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:POWer:MGAP {param}')

	def get_timeout(self) -> float or bool:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:TOUT \n
		Snippet: value: float or bool = driver.trigger.gprfMeasurement.power.get_timeout() \n
		Specifies the time after which an initiated measurement must have received a trigger event. If no trigger event is
		received, the measurement is stopped in remote control mode. In manual operation mode, a trigger timeout is indicated.
		This setting is relevant for the trigger source 'IF Power' and for trigger signals at TRIG IN. \n
			:return: timeout: Range: 0.01 s to 300 s, Unit: s
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:POWer:TOUT?')
		return Conversions.str_to_float_or_bool(response)

	def set_timeout(self, timeout: float or bool) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:TOUT \n
		Snippet: driver.trigger.gprfMeasurement.power.set_timeout(timeout = 1.0) \n
		Specifies the time after which an initiated measurement must have received a trigger event. If no trigger event is
		received, the measurement is stopped in remote control mode. In manual operation mode, a trigger timeout is indicated.
		This setting is relevant for the trigger source 'IF Power' and for trigger signals at TRIG IN. \n
			:param timeout: Range: 0.01 s to 300 s, Unit: s
		"""
		param = Conversions.decimal_or_bool_value_to_str(timeout)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:POWer:TOUT {param}')

	def get_offset(self) -> float:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:OFFSet \n
		Snippet: value: float = driver.trigger.gprfMeasurement.power.get_offset() \n
		Defines a delay time for triggered measurements. The trigger offset delays the start of the measurement relative to the
		trigger event. \n
			:return: offset: Range: 0 s to 1 s, Unit: s
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:POWer:OFFSet?')
		return Conversions.str_to_float(response)

	def set_offset(self, offset: float) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:OFFSet \n
		Snippet: driver.trigger.gprfMeasurement.power.set_offset(offset = 1.0) \n
		Defines a delay time for triggered measurements. The trigger offset delays the start of the measurement relative to the
		trigger event. \n
			:param offset: Range: 0 s to 1 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:POWer:OFFSet {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.PowerMode:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:MODE \n
		Snippet: value: enums.PowerMode = driver.trigger.gprfMeasurement.power.get_mode() \n
		Selects the trigger mode for the measurement. This setting is relevant for the trigger source 'IF Power' and for trigger
		signals at TRIG IN. \n
			:return: mode: ONCE | SWEep | ALL ONCE Only the start of the measurement is triggered SWEep Each measurement cycle is triggered ALL Each measurement interval is triggered
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:POWer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PowerMode)

	def set_mode(self, mode: enums.PowerMode) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:MODE \n
		Snippet: driver.trigger.gprfMeasurement.power.set_mode(mode = enums.PowerMode.ALL) \n
		Selects the trigger mode for the measurement. This setting is relevant for the trigger source 'IF Power' and for trigger
		signals at TRIG IN. \n
			:param mode: ONCE | SWEep | ALL ONCE Only the start of the measurement is triggered SWEep Each measurement cycle is triggered ALL Each measurement interval is triggered
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PowerMode)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:POWer:MODE {param}')

	def get_threshold(self) -> float:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:THReshold \n
		Snippet: value: float = driver.trigger.gprfMeasurement.power.get_threshold() \n
		Defines the trigger threshold for trigger source 'IF Power'. \n
			:return: threshold: Range: -50 dB to 0 dB, Unit: dB (full scale, i.e. relative to expected power minus external attenuation)
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:POWer:THReshold?')
		return Conversions.str_to_float(response)

	def set_threshold(self, threshold: float) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:THReshold \n
		Snippet: driver.trigger.gprfMeasurement.power.set_threshold(threshold = 1.0) \n
		Defines the trigger threshold for trigger source 'IF Power'. \n
			:param threshold: Range: -50 dB to 0 dB, Unit: dB (full scale, i.e. relative to expected power minus external attenuation)
		"""
		param = Conversions.decimal_value_to_str(threshold)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:POWer:THReshold {param}')

	# noinspection PyTypeChecker
	def get_slope(self) -> enums.SignalSlopeExt:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:SLOPe \n
		Snippet: value: enums.SignalSlopeExt = driver.trigger.gprfMeasurement.power.get_slope() \n
		Selects whether the trigger event is generated at the rising or at the falling edge of the trigger pulse. This command is
		relevant for the trigger source 'IF Power'. \n
			:return: event: REDGe | FEDGe | RISing | FALLing REDGe, RISing Rising edge FEDGe, FALLing Falling edge
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:POWer:SLOPe?')
		return Conversions.str_to_scalar_enum(response, enums.SignalSlopeExt)

	def set_slope(self, event: enums.SignalSlopeExt) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:POWer:SLOPe \n
		Snippet: driver.trigger.gprfMeasurement.power.set_slope(event = enums.SignalSlopeExt.FALLing) \n
		Selects whether the trigger event is generated at the rising or at the falling edge of the trigger pulse. This command is
		relevant for the trigger source 'IF Power'. \n
			:param event: REDGe | FEDGe | RISing | FALLing REDGe, RISing Rising edge FEDGe, FALLing Falling edge
		"""
		param = Conversions.enum_scalar_to_str(event, enums.SignalSlopeExt)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:POWer:SLOPe {param}')

	def clone(self) -> 'Power':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Power(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spectrum:
	"""Spectrum commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spectrum", core, parent)

	@property
	def application(self):
		"""application commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_application'):
			from .Spectrum_.Application import Application
			self._application = Application(self._core, self._base)
		return self._application

	# noinspection PyTypeChecker
	class TraceStruct(StructBase):
		"""Structure for setting input parameters. Contains optional set arguments. Fields: \n
			- Trace_Enable: bool: OFF | ON Disables or enables the trace selected via Trace
			- Trace: enums.Statistic: Optional setting parameter. CURRent | AVERage | MAXimum | MINimum Selects the trace to be enabled/disabled To enable or disable all traces, omit the parameter."""
		__meta_args_list = [
			ArgStruct.scalar_bool('Trace_Enable'),
			ArgStruct.scalar_enum_optional('Trace', enums.Statistic)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Trace_Enable: bool = None
			self.Trace: enums.Statistic = None

	def set_trace(self, value: TraceStruct) -> None:
		"""SCPI: DISPlay:GPRF:MEASurement<Instance>:SPECtrum:TRACe \n
		Snippet: driver.display.gprfMeasurement.spectrum.set_trace(value = TraceStruct()) \n
		Selects which traces are displayed on the 'Spectrum Analyzer' tab. \n
			:param value: see the help for TraceStruct structure arguments.
		"""
		self._core.io.write_struct('DISPlay:GPRF:MEASurement<Instance>:SPECtrum:TRACe', value)

	def clone(self) -> 'Spectrum':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Spectrum(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Absolute:
	"""Absolute commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("absolute", core, parent)

	# noinspection PyTypeChecker
	class FetchStruct(StructBase):
		"""Response structure. Fields: \n
			- Xvalue: float: X-value of the marker Unit: Hz
			- Yvalue: float: Y-value of the marker Unit: Depends on input path and demodulation type"""
		__meta_args_list = [
			ArgStruct.scalar_float('Xvalue'),
			ArgStruct.scalar_float('Yvalue')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Xvalue: float = None
			self.Yvalue: float = None

	def fetch(self, trace: enums.Statistic, function: enums.MarkerFunction = None, audioInput=repcap.AudioInput.Default, marker=repcap.Marker.Nr1) -> FetchStruct:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:AIN<nr>:MARKer<mnr>:ABSolute \n
		Snippet: value: FetchStruct = driver.afRf.measurement.multiEval.fft.audioInput.marker.absolute.fetch(trace = enums.Statistic.AVERage, function = enums.MarkerFunction.MAX, audioInput = repcap.AudioInput.Default, marker = repcap.Marker.Nr1) \n
		Queries the absolute coordinates of marker number <mnr>. Select the trace to be evaluated. Optionally, you can perform a
		marker action before reading the position. \n
			:param trace: CURRent | AVERage | MAXimum | MINimum Selects the trace type
			:param function: MIN | MAX | MAXL | MAXR | MAXN Marker action to be performed before the query MIN Search the absolute minimum of the entire trace MAX Search the absolute maximum of the entire trace MAXL Search the absolute maximum to the left of the current marker position MAXR Search the absolute maximum to the right of the current marker position MAXN Search the next lower peak of the entire trace
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:param marker: optional repeated capability selector. Default value: Nr1
			:return: structure: for return value, see the help for FetchStruct structure arguments."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('trace', trace, DataType.Enum), ArgSingle('function', function, DataType.Enum, True))
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		marker_cmd_val = self._base.get_repcap_cmd_value(marker, repcap.Marker)
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:AIN{audioInput_cmd_val}:MARKer{marker_cmd_val}:ABSolute? {param}'.rstrip(), self.__class__.FetchStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Measurement:
	"""Measurement commands group definition. 346 total commands, 15 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("measurement", core, parent)

	@property
	def data(self):
		"""data commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Measurement_.Data import Data
			self._data = Data(self._core, self._base)
		return self._data

	@property
	def delta(self):
		"""delta commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_delta'):
			from .Measurement_.Delta import Delta
			self._delta = Delta(self._core, self._base)
		return self._delta

	@property
	def voip(self):
		"""voip commands group. 7 Sub-classes, 4 commands."""
		if not hasattr(self, '_voip'):
			from .Measurement_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	@property
	def spdif(self):
		"""spdif commands group. 3 Sub-classes, 3 commands."""
		if not hasattr(self, '_spdif'):
			from .Measurement_.Spdif import Spdif
			self._spdif = Spdif(self._core, self._base)
		return self._spdif

	@property
	def audioInput(self):
		"""audioInput commands group. 12 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioInput'):
			from .Measurement_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	@property
	def demodulation(self):
		"""demodulation commands group. 5 Sub-classes, 4 commands."""
		if not hasattr(self, '_demodulation'):
			from .Measurement_.Demodulation import Demodulation
			self._demodulation = Demodulation(self._core, self._base)
		return self._demodulation

	@property
	def rfCarrier(self):
		"""rfCarrier commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rfCarrier'):
			from .Measurement_.RfCarrier import RfCarrier
			self._rfCarrier = RfCarrier(self._core, self._base)
		return self._rfCarrier

	@property
	def searchRoutines(self):
		"""searchRoutines commands group. 8 Sub-classes, 5 commands."""
		if not hasattr(self, '_searchRoutines'):
			from .Measurement_.SearchRoutines import SearchRoutines
			self._searchRoutines = SearchRoutines(self._core, self._base)
		return self._searchRoutines

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Measurement_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def multiEval(self):
		"""multiEval commands group. 14 Sub-classes, 8 commands."""
		if not hasattr(self, '_multiEval'):
			from .Measurement_.MultiEval import MultiEval
			self._multiEval = MultiEval(self._core, self._base)
		return self._multiEval

	@property
	def rfSettings(self):
		"""rfSettings commands group. 2 Sub-classes, 8 commands."""
		if not hasattr(self, '_rfSettings'):
			from .Measurement_.RfSettings import RfSettings
			self._rfSettings = RfSettings(self._core, self._base)
		return self._rfSettings

	@property
	def cdefinition(self):
		"""cdefinition commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_cdefinition'):
			from .Measurement_.Cdefinition import Cdefinition
			self._cdefinition = Cdefinition(self._core, self._base)
		return self._cdefinition

	@property
	def audioOutput(self):
		"""audioOutput commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioOutput'):
			from .Measurement_.AudioOutput import AudioOutput
			self._audioOutput = AudioOutput(self._core, self._base)
		return self._audioOutput

	@property
	def sout(self):
		"""sout commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_sout'):
			from .Measurement_.Sout import Sout
			self._sout = Sout(self._core, self._base)
		return self._sout

	@property
	def filterPy(self):
		"""filterPy commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_filterPy'):
			from .Measurement_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	def clone(self) -> 'Measurement':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Measurement(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Time:
	"""Time commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("time", core, parent)

	# noinspection PyTypeChecker
	class TzoneStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Hour: int: No parameter help available
			- Minute: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Hour'),
			ArgStruct.scalar_int('Minute')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Hour: int = None
			self.Minute: int = None

	def get_tzone(self) -> TzoneStruct:
		"""SCPI: SYSTem:BASE:TIME:TZONe \n
		Snippet: value: TzoneStruct = driver.system.base.time.get_tzone() \n
		No command help available \n
			:return: structure: for return value, see the help for TzoneStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:BASE:TIME:TZONe?', self.__class__.TzoneStruct())

	def set_tzone(self, value: TzoneStruct) -> None:
		"""SCPI: SYSTem:BASE:TIME:TZONe \n
		Snippet: driver.system.base.time.set_tzone(value = TzoneStruct()) \n
		No command help available \n
			:param value: see the help for TzoneStruct structure arguments.
		"""
		self._core.io.write_struct('SYSTem:BASE:TIME:TZONe', value)

	# noinspection PyTypeChecker
	class ValueStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Hour: int: No parameter help available
			- Min: int: No parameter help available
			- Sec: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Hour'),
			ArgStruct.scalar_int('Min'),
			ArgStruct.scalar_int('Sec')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Hour: int = None
			self.Min: int = None
			self.Sec: int = None

	def get_value(self) -> ValueStruct:
		"""SCPI: SYSTem:BASE:TIME \n
		Snippet: value: ValueStruct = driver.system.base.time.get_value() \n
		No command help available \n
			:return: structure: for return value, see the help for ValueStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:BASE:TIME?', self.__class__.ValueStruct())

	def set_value(self, value: ValueStruct) -> None:
		"""SCPI: SYSTem:BASE:TIME \n
		Snippet: driver.system.base.time.set_value(value = ValueStruct()) \n
		No command help available \n
			:param value: see the help for ValueStruct structure arguments.
		"""
		self._core.io.write_struct('SYSTem:BASE:TIME', value)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nxdn:
	"""Nxdn commands group definition. 5 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nxdn", core, parent)

	@property
	def ffError(self):
		"""ffError commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ffError'):
			from .Nxdn_.FfError import FfError
			self._ffError = FfError(self._core, self._base)
		return self._ffError

	@property
	def merror(self):
		"""merror commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_merror'):
			from .Nxdn_.Merror import Merror
			self._merror = Merror(self._core, self._base)
		return self._merror

	# noinspection PyTypeChecker
	class FdErrorStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON
			- Limit: float: Range: 0 Hz to 1 MHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Limit')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Limit: float = None

	def get_fd_error(self) -> FdErrorStruct:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:LIMit:NXDN:FDERor \n
		Snippet: value: FdErrorStruct = driver.configure.vse.measurement.limit.nxdn.get_fd_error() \n
		Enables/disables limit evaluation and sets the upper limit for the FSK deviation error. \n
			:return: structure: for return value, see the help for FdErrorStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:VSE:MEASurement<Instance>:LIMit:NXDN:FDERor?', self.__class__.FdErrorStruct())

	def set_fd_error(self, value: FdErrorStruct) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:LIMit:NXDN:FDERor \n
		Snippet: driver.configure.vse.measurement.limit.nxdn.set_fd_error(value = FdErrorStruct()) \n
		Enables/disables limit evaluation and sets the upper limit for the FSK deviation error. \n
			:param value: see the help for FdErrorStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:VSE:MEASurement<Instance>:LIMit:NXDN:FDERor', value)

	def clone(self) -> 'Nxdn':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Nxdn(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nxdn:
	"""Nxdn commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nxdn", core, parent)

	@property
	def filterPy(self):
		"""filterPy commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_filterPy'):
			from .Nxdn_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	# noinspection PyTypeChecker
	def get_transmission(self) -> enums.Transmission:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:NXDN:TRANsmission \n
		Snippet: value: enums.Transmission = driver.configure.vse.measurement.nxdn.get_transmission() \n
		Queries the data rate in bits/s for enhanced full rate (EFR) or enhanced half rate (EHR) . \n
			:return: transmission: EHR4800 | EHR9600 | EFR9600
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:NXDN:TRANsmission?')
		return Conversions.str_to_scalar_enum(response, enums.Transmission)

	def set_transmission(self, transmission: enums.Transmission) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:NXDN:TRANsmission \n
		Snippet: driver.configure.vse.measurement.nxdn.set_transmission(transmission = enums.Transmission.EFR9600) \n
		Queries the data rate in bits/s for enhanced full rate (EFR) or enhanced half rate (EHR) . \n
			:param transmission: EHR4800 | EHR9600 | EFR9600
		"""
		param = Conversions.enum_scalar_to_str(transmission, enums.Transmission)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:NXDN:TRANsmission {param}')

	def clone(self) -> 'Nxdn':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Nxdn(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Marker:
	"""Marker commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("marker", core, parent)

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .Marker_.Enable import Enable
			self._enable = Enable(self._core, self._base)
		return self._enable

	# noinspection PyTypeChecker
	def get_detector(self) -> enums.Detector:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:MARKer:DETector \n
		Snippet: value: enums.Detector = driver.configure.gprfMeasurement.spectrum.marker.get_detector() \n
		Selects the detector used to calculate the 1001 values of the result traces from the raw set of samples. \n
			:return: detector: AVERage | RMS | SAMPle | MINPeak | MAXPeak | AUTopeak
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:MARKer:DETector?')
		return Conversions.str_to_scalar_enum(response, enums.Detector)

	def set_detector(self, detector: enums.Detector) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:MARKer:DETector \n
		Snippet: driver.configure.gprfMeasurement.spectrum.marker.set_detector(detector = enums.Detector.AUTopeak) \n
		Selects the detector used to calculate the 1001 values of the result traces from the raw set of samples. \n
			:param detector: AVERage | RMS | SAMPle | MINPeak | MAXPeak | AUTopeak
		"""
		param = Conversions.enum_scalar_to_str(detector, enums.Detector)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:MARKer:DETector {param}')

	def clone(self) -> 'Marker':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Marker(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePy:
	"""TypePy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("typePy", core, parent)

	def set(self, filter_type: enums.RbwFilterType, standard: enums.Standard = None) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:FILTer:TYPE \n
		Snippet: driver.configure.vse.measurement.iqRecorder.filterPy.typePy.set(filter_type = enums.RbwFilterType.BANDpass, standard = enums.Standard.CUSTom) \n
		Selects or queries the type of filter to be applied to the data after demodulation and the related digital standard. \n
			:param filter_type: BANDpass | GAUSs
			:param standard: DMR | NXDN | P25 | TETRa | LTE | UDEFined
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('filter_type', filter_type, DataType.Enum), ArgSingle('standard', standard, DataType.Enum, True))
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:FILTer:TYPE {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self) -> enums.RbwFilterType:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:FILTer:TYPE \n
		Snippet: value: enums.RbwFilterType = driver.configure.vse.measurement.iqRecorder.filterPy.typePy.get() \n
		Selects or queries the type of filter to be applied to the data after demodulation and the related digital standard. \n
			:return: filter_type: BANDpass | GAUSs"""
		response = self._core.io.query_str(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:FILTer:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.RbwFilterType)



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sense:
	"""Sense commands group definition. 17 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sense", core, parent)

	@property
	def base(self):
		"""base commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_base'):
			from .Sense_.Base import Base
			self._base = Base(self._core, self._base)
		return self._base

	@property
	def sequencer(self):
		"""sequencer commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sequencer'):
			from .Sense_.Sequencer import Sequencer
			self._sequencer = Sequencer(self._core, self._base)
		return self._sequencer

	@property
	def display(self):
		"""display commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_display'):
			from .Sense_.Display import Display
			self._display = Display(self._core, self._base)
		return self._display

	@property
	def firmwareUpdate(self):
		"""firmwareUpdate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_firmwareUpdate'):
			from .Sense_.FirmwareUpdate import FirmwareUpdate
			self._firmwareUpdate = FirmwareUpdate(self._core, self._base)
		return self._firmwareUpdate

	def clone(self) -> 'Sense':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sense(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Vswr:
	"""Vswr commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("vswr", core, parent)

	def get_mode(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:VSWR:MODE \n
		Snippet: value: bool = driver.configure.gprfMeasurement.spectrum.vswr.get_mode() \n
		No command help available \n
			:return: vswr_mode: No help available
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:VSWR:MODE?')
		return Conversions.str_to_bool(response)

	def set_mode(self, vswr_mode: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:VSWR:MODE \n
		Snippet: driver.configure.gprfMeasurement.spectrum.vswr.set_mode(vswr_mode = False) \n
		No command help available \n
			:param vswr_mode: No help available
		"""
		param = Conversions.bool_to_str(vswr_mode)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:VSWR:MODE {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bits:
	"""Bits commands group definition. 3 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bits", core, parent)

	@property
	def cataloge(self):
		"""cataloge commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cataloge'):
			from .Bits_.Cataloge import Cataloge
			self._cataloge = Cataloge(self._core, self._base)
		return self._cataloge

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .Bits_.All import All
			self._all = All(self._core, self._base)
		return self._all

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Bits_.Count import Count
			self._count = Count(self._core, self._base)
		return self._count

	def clone(self) -> 'Bits':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Bits(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Update:
	"""Update commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("update", core, parent)

	def get_dgroup(self) -> str:
		"""SCPI: SYSTem:UPDate:DGRoup \n
		Snippet: value: str = driver.system.update.get_dgroup() \n
		No command help available \n
			:return: devicegroup: No help available
		"""
		response = self._core.io.query_str('SYSTem:UPDate:DGRoup?')
		return trim_str_response(response)

	def set_dgroup(self, devicegroup: str) -> None:
		"""SCPI: SYSTem:UPDate:DGRoup \n
		Snippet: driver.system.update.set_dgroup(devicegroup = '1') \n
		No command help available \n
			:param devicegroup: No help available
		"""
		param = Conversions.value_to_quoted_str(devicegroup)
		self._core.io.write(f'SYSTem:UPDate:DGRoup {param}')
